# coding: utf-8

"""
    Insights.Api

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import elexonpy
from elexonpy.api.reference_api import ReferenceApi  # noqa: E501
from elexonpy.rest import ApiException


class TestReferenceApi(unittest.TestCase):
    """ReferenceApi unit test stubs"""

    def setUp(self):
        self.api = ReferenceApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_reference_bmunits_all_get(self):
        """Test case for reference_bmunits_all_get

        BM Units  # noqa: E501
        """
        pass

    def test_reference_fueltypes_all_get(self):
        """Test case for reference_fueltypes_all_get

        Fuel types  # noqa: E501
        """
        pass

    def test_reference_interconnectors_all_get(self):
        """Test case for reference_interconnectors_all_get

        Interconnectors  # noqa: E501
        """
        pass

    def test_reference_remit_assets_all_get(self):
        """Test case for reference_remit_assets_all_get

        Assets  # noqa: E501
        """
        pass

    def test_reference_remit_fueltypes_all_get(self):
        """Test case for reference_remit_fueltypes_all_get

        REMIT fuel types  # noqa: E501
        """
        pass

    def test_reference_remit_participants_all_get(self):
        """Test case for reference_remit_participants_all_get

        Participants  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
