# coding: utf-8

"""
    Insights.Api

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import elexonpy
from elexonpy.models.insights_api_models_responses_demand_outturn_rolling_system_demand import InsightsApiModelsResponsesDemandOutturnRollingSystemDemand  # noqa: E501
from elexonpy.rest import ApiException


class TestInsightsApiModelsResponsesDemandOutturnRollingSystemDemand(unittest.TestCase):
    """InsightsApiModelsResponsesDemandOutturnRollingSystemDemand unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testInsightsApiModelsResponsesDemandOutturnRollingSystemDemand(self):
        """Test InsightsApiModelsResponsesDemandOutturnRollingSystemDemand"""
        # FIXME: construct object with mandatory attributes with example values
        # model = elexonpy.models.insights_api_models_responses_demand_outturn_rolling_system_demand.InsightsApiModelsResponsesDemandOutturnRollingSystemDemand()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
