# coding: utf-8

"""
    Insights.Api

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import elexonpy
from elexonpy.api.loss_of_load_probability_and_de_rated_margin_api import LossOfLoadProbabilityAndDeRatedMarginApi  # noqa: E501
from elexonpy.rest import ApiException


class TestLossOfLoadProbabilityAndDeRatedMarginApi(unittest.TestCase):
    """LossOfLoadProbabilityAndDeRatedMarginApi unit test stubs"""

    def setUp(self):
        self.api = LossOfLoadProbabilityAndDeRatedMarginApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_lolpdrm_forecast_evolution_get(self):
        """Test case for lolpdrm_forecast_evolution_get

        Loss of load probability and de-rated margin forecast (LOLPDRM)  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
