# coding: utf-8

"""
    Insights.Api

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import elexonpy
from elexonpy.models.insights_api_models_responses_dataset_response1_insights_api_models_responses_balancing_dynamic_dataset_rows_delivery_period_min_data import InsightsApiModelsResponsesDatasetResponse1InsightsApiModelsResponsesBalancingDynamicDatasetRowsDeliveryPeriodMinData  # noqa: E501
from elexonpy.rest import ApiException


class TestInsightsApiModelsResponsesDatasetResponse1InsightsApiModelsResponsesBalancingDynamicDatasetRowsDeliveryPeriodMinData(unittest.TestCase):
    """InsightsApiModelsResponsesDatasetResponse1InsightsApiModelsResponsesBalancingDynamicDatasetRowsDeliveryPeriodMinData unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testInsightsApiModelsResponsesDatasetResponse1InsightsApiModelsResponsesBalancingDynamicDatasetRowsDeliveryPeriodMinData(self):
        """Test InsightsApiModelsResponsesDatasetResponse1InsightsApiModelsResponsesBalancingDynamicDatasetRowsDeliveryPeriodMinData"""
        # FIXME: construct object with mandatory attributes with example values
        # model = elexonpy.models.insights_api_models_responses_dataset_response1_insights_api_models_responses_balancing_dynamic_dataset_rows_delivery_period_min_data.InsightsApiModelsResponsesDatasetResponse1InsightsApiModelsResponsesBalancingDynamicDatasetRowsDeliveryPeriodMinData()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
